/** Copyright (C) 2017 by Bundesanstalt für Gewässerkunde
 * Software engineering by
 *  Björnsen Beratende Ingenieure GmbH
 *  Dr. Schumacher Ingenieurbüro für Wasser und Umwelt
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */

package org.dive4elements.river.artifacts.sinfo.flood_duration;

import org.apache.log4j.Logger;
import org.dive4elements.artifactdatabase.state.DefaultFacet;
import org.dive4elements.artifactdatabase.state.Facet;
import org.dive4elements.artifacts.Artifact;
import org.dive4elements.artifacts.CallContext;
import org.dive4elements.river.artifacts.D4EArtifact;
import org.dive4elements.river.artifacts.sinfo.SINFOArtifact;
import org.dive4elements.river.exports.fixings.FixChartGenerator;


/**
 * Data of a flood duration curve.
 */
public class FloodDurationCurveFacet extends DefaultFacet {

    private static final long serialVersionUID = 1L;

    private static Logger log = Logger.getLogger(FloodDurationCurveFacet.class);

    public FloodDurationCurveFacet() {
    }

    public FloodDurationCurveFacet(final String name, final String description) {
        super(0, name, description);
    }


    /**
     * Expose state computation from SINFOArtifact.
     */
    @Override
    public Object getData(final Artifact artifact, final CallContext context) {

        log.debug("Get data for flood duration curve data");

        final D4EArtifact flys = (D4EArtifact) artifact;

        final double currentKm = FixChartGenerator.getCurrentKm(context);
        return new FloodDurationCalculation(context).calcStationCurve(currentKm, (SINFOArtifact) flys);
    }


    /** Create a deep copy. */
    @Override
    public Facet deepCopy() {
        final FloodDurationCurveFacet copy = new FloodDurationCurveFacet();
        copy.set(this);
        return copy;
    }
}

